API docs for “spamfighter.interfaces.IMessageLog”

# Class s.i.IMessageLog(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Лог сообщений, проходящих через сервер.

Method | put | Поместить новое сообщение в лог.
Method | fetch | Произвести выборку сообщений из лога по указанным критериям выборки.

def put(message, when=None, tags=None): (source)
Поместить новое сообщение в лог.

Parameters | when | дата/время записи в логе, UTC (type: `int` )
| message | само сообщение (type: `IMessage` или `ITaggedMessage` )
| tags | тэги, привзяанные к сообщению (type: `list(str)` )
Returns | Deferred о завершении операции (type: `twisted.internet.defer.Deferred` )

def fetch(first=None, last=None, firstID=None): (source)
Произвести выборку сообщений из лога по указанным критериям выборки.

Parameters | first | минимальная дата возвращаемого сообщения (type: `int` )
| last | максимальная дата возвращаемого сообщения (type: `int` )
| firstID | минимальный ID элемента лога, который будет возвращен (type: `int` )
Returns | Deferred с `list(``ILogEntry``)` (type: `twisted.internet.defer.Deferred` )